from setuptools import setup



setup(
    name="skidbilly",
    version='1.0',
    license='Eclipse Public License 2.0',
    authors=["Bernward"],
    author_email="<contact@bern.codes>",
    description="reuploaded",
    long_description='reuploaded',
    keywords=['cli', 'fade', 'colors', 'terminal', 'tui'],
    package_dir={"": "src"},
    package_data={'': ['**/*']}
)